@@ -10,6 +10,10 @@ class DarkKeeperCacheReadError(DarkKeeperCacheError):
     pass
 
 
+class DarkKeeperCacheWriteError(DarkKeeperCacheError):
+    pass
+
+
 class DarkKeeperParseError(DarkKeeperError):
     pass
 
@@ -24,3 +28,11 @@ class DarkKeeperRequestError(DarkKeeperError):
 
 class DarkKeeperRequestResponseError(DarkKeeperRequestError):
     pass
+
+
+class DarkKeeperMongoError(DarkKeeperError):
+    pass
+
+
+class DarkKeeperParseUriMongoError(DarkKeeperMongoError):
+    pass
